@@ -11,15 +11,10 @@ use warnings;
 use version;
 use Carp;
 use Scalar::Util qw/openhandle/;
-use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use Path::Class;
 use AnyEvent;
 
-our $VERSION     = version->new('0.3.6');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION = version->new('0.4.0');
 
 has name => (
     is            => 'rw',
@@ -276,7 +271,7 @@ Tail::Tool::File - Looks after individual files
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::File version 0.3.6.
+This documentation refers to Tail::Tool::File version 0.4.0.
 
 =head1 SYNOPSIS
 
