@@ -10,20 +10,13 @@ use Moose;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
-use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use AnyEvent;
 
 extends 'Tail::Tool::PreProcess';
 with 'Tail::Tool::RegexList';
 
-our $VERSION     = version->new('0.3.6');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION = version->new('0.4.0');
 
 has end => (
     is   => 'rw',
@@ -91,7 +84,7 @@ Tail::Tool::Plugin::GroupLines - Groups real lines of a log file so that other p
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::Plugin::GroupLines version 0.3.6.
+This documentation refers to Tail::Tool::Plugin::GroupLines version 0.4.0.
 
 =head1 SYNOPSIS
 
