@@ -10,10 +10,6 @@ use Moose;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
-use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Term::ANSIColor;
 use Readonly;
@@ -21,10 +17,8 @@ use Readonly;
 extends 'Tail::Tool::PostProcess';
 with 'Tail::Tool::RegexList';
 
-our $VERSION     = version->new('0.3.6');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION = version->new('0.4.0');
+
 Readonly my @COLOURS => qw/
     red
     green
@@ -115,7 +109,7 @@ Tail::Tool::Plugin::Highlight - Highlights any text that matches the supplied re
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::Plugin::Highlight version 0.3.6.
+This documentation refers to Tail::Tool::Plugin::Highlight version 0.4.0.
 
 
 =head1 SYNOPSIS
