@@ -10,19 +10,12 @@ use Moose;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
-use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
 extends 'Tail::Tool::PreProcess';
 with 'Tail::Tool::RegexList';
 
-our $VERSION     = version->new('0.3.6');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION = version->new('0.4.0');
 
 sub process {
     my ($self, $line) = @_;
@@ -51,7 +44,7 @@ Tail::Tool::Plugin::Ignore - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::Plugin::Ignore version 0.3.6.
+This documentation refers to Tail::Tool::Plugin::Ignore version 0.4.0.
 
 
 =head1 SYNOPSIS
