@@ -10,17 +10,9 @@ use Moose;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
-use List::Util;
-#use List::MoreUtils;
-use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-
-our $VERSION     = version->new('0.3.6');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION = version->new('0.4.0');
 
 has post => (
     is       => 'ro',
@@ -46,7 +38,7 @@ Tail::Tool::PreProcess - Parent module for Plugins that perform pre-processing t
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::PreProcess version 0.3.6.
+This documentation refers to Tail::Tool::PreProcess version 0.4.0.
 
 
 =head1 SYNOPSIS
